@@ -16,7 +16,7 @@ extern "C"
 #endif
 #include "libmaix_cam.h"
 #include "libmaix_image.h"
-#define debug_line printf("%s:%d %s %s %s \r\n", __FILE__, __LINE__, __FUNCTION__, __DATE__, __TIME__)
+#define debug_line // printf("%s:%d %s %s %s \r\n", __FILE__, __LINE__, __FUNCTION__, __DATE__, __TIME__)
 #ifdef __cplusplus
 }
 #endif
