@@ -114,7 +114,7 @@ public:
   int len__();
   void _show();
   int _save(std::string file_path, std::string format);
-  py::bytes _tobytes();
+  py::bytes _tobytes(std::string format, std::vector<int> params);
   size_t img_pointer();
   maix_image &_new(std::vector<int> size, std::vector<int> color, std::string mode);
   maix_image &_load(py::object data, std::vector<int> size, std::string mode);
@@ -124,7 +124,7 @@ public:
   maix_image &_clear();
   void _load_freetype(std::string path);
   py::tuple _get_string_size(std::string str, double scale, int thickness);
-  maix_image &_resize(int w, int h, int func);
+  maix_image &_resize(int w, int h, int func, int padding, std::vector<int> size);
   maix_image &_draw_line(int x1, int y1, int x2, int y2, std::vector<int> color, int thickness);
   maix_image &_draw_cross(int x, int y, int c, int size, int thickness);
   maix_image &_draw_rectangle(int x1_x, int y1_y, int x2_w, int y2_h, std::vector<int> color, int thickness, int is_xywh);
@@ -206,5 +206,6 @@ public:
 
   maix_image &_mean(const int ksize, bool threshold, int offset,bool invert,maix_image & mask);
 
+  maix_image &_opencv_Canny(double threshold1, double threshold2, int apertureSize, bool L2gradient);
 };
 #endif
\ No newline at end of file
