@@ -118,8 +118,8 @@ PYBIND11_MODULE(_maix_image, mo)
         .def("clear", &maix_image::_clear)
         .def("delete", &maix_image::_delete)
         .def("save", &maix_image::_save, py::arg("path"), py::arg("format") = "jpeg")
-        .def("tobytes", &maix_image::_tobytes)
-        .def("resize", &maix_image::_resize, py::arg("w"), py::arg("h"), py::arg("func") = 1)
+        .def("tobytes", &maix_image::_tobytes, py::arg("format")="rgb", py::arg("params") = std::vector<int>{})
+        .def("resize", &maix_image::_resize, py::arg("w") = 0, py::arg("h") = 0, py::arg("func") = 1, py::arg("padding") = 1, py::arg("size") = std::vector<int>{0, 0})
         .def("draw_line", &maix_image::_draw_line, py::arg("x1"), py::arg("y1"), py::arg("x2"), py::arg("y2"), py::arg("color") = std::vector<int>{127, 127, 127}, py::arg("thickness") = 1)
         .def("draw_cross", &maix_image::_draw_cross, py::arg("x"), py::arg("y"), py::arg("c"), py::arg("size") = 5, py::arg("thickness") = 1)
         .def("draw_rectangle", &maix_image::_draw_rectangle, py::arg("x1_x"), py::arg("y1_y"), py::arg("x2_w"), py::arg("y2_h"), py::arg("color") = std::vector<int>{127, 127, 127}, py::arg("thickness") = 1, py::arg("is_xywh") = 0)
@@ -136,6 +136,8 @@ PYBIND11_MODULE(_maix_image, mo)
         .def("show", &maix_image::_show)
         .def("get_pixel", &maix_image::_get_pixel, py::arg("x"), py::arg("y"))
         .def("set_pixel", &maix_image::_set_pixel, py::arg("x"), py::arg("y"), py::arg("color"))
+        .def("Canny",&maix_image::_opencv_Canny, py::arg("threshold1") = 10, py::arg("threshold2") = 100, py::arg("apertureSize") = 3, py::arg("L2gradient") = false)
+
         //maix_image继承maix_vision方法
         .def("get_blob_lab", &maix_image::get_blob_color_max, py::arg("roi") = std::vector<int>{0, 0, 0, 0}, py::arg("critical") = 0, py::arg("co") = 0)
         .def("get_blob_color", &maix_image::get_blob_color_max, py::arg("roi") = std::vector<int>{0, 0, 0, 0}, py::arg("critical") = 0, py::arg("co") = 0)
