@@ -5,7 +5,7 @@ model = {
 }
 
 options = {
-    "model_type":  "normal",
+    "model_type":  "aipu",
     "inputs": {
         "input0": (224, 224, 3)
     },
