@@ -54,6 +54,7 @@ static void Model_del(ModelObject *self)
     if(self->nn)
     {
         libmaix_nn_destroy(&(self->nn));
+        // printf("libmaix_nn_module_deinit %s:%s\r\n", __FILE__, __FUNCTION__);
         libmaix_nn_module_deinit();
     }
     if(Py_TYPE(self)->tp_free)
@@ -176,6 +177,8 @@ static int Model_init(ModelObject *self, PyObject *args, PyObject *kwds)
         Py_INCREF(self->outputs);
 
         /* load by libmaix API */
+        // printf("libmaix_nn_module_init %s:%s\r\n", __FILE__, __FUNCTION__);
+        libmaix_camera_module_init();
         libmaix_nn_module_init();
         libmaix_nn_model_path_t model_path = {
             .awnn.param_path = (char*)PyUnicode_DATA(o_param_path),
@@ -363,6 +366,8 @@ static int Model_init(ModelObject *self, PyObject *args, PyObject *kwds)
         Py_INCREF(self->outputs);
 
         /* load by libmaix API */
+        // printf("libmaix_nn_module_init %s:%s\r\n", __FILE__, __FUNCTION__);
+        libmaix_camera_module_init();
         libmaix_nn_module_init();
         libmaix_nn_model_path_t model_path = {
             .aipu.model_path = (char*)PyUnicode_DATA(o_bin_path),
@@ -543,6 +548,7 @@ end:
     {
         libmaix_nn_destroy(&(self->nn));
     }
+    // printf("libmaix_nn_module_deinit %s:%s\r\n", __FILE__, __FUNCTION__);
     libmaix_nn_module_deinit();
     /* load by libmaix API error deal end*/
     return (int)err;
