@@ -24,7 +24,7 @@ typedef struct ini_info
     int inputs_shape[MAX_LEN][3];
 }ini_info_t;
 
-FILE * load_file(char *filename);
+FILE * load_file(char *mud_path);
 char * get_key(char * line);
 float * get_float_value(char *line);
 char * get_sting_value(char *line);
@@ -35,8 +35,9 @@ void set_outputs_scale(float * values , ini_info_t * ini_info);
 int get_section(FILE * fp , char *title , ini_info_t * ini_info);
 void read_file(char * mdsc_path , ini_info_t * ini_info_ptr);
 libmaix_nn_t* load_mdsc(char * path , ini_info_t * info_ptr);
-// libmaix_nn_t* build_model(ini_info_t * info_ptr);
 libmaix_nn_t* build_model(ini_info_t * info_ptr ,libmaix_nn_model_path_t * path, libmaix_nn_opt_param_t *opt);
+char *get_dirpath_from_str(char * path);
+char *get_filename_from_str(char * path);
 #ifdef __cplusplus
 }
 #endif
