@@ -4,7 +4,9 @@
 #include <stdio.h>
 #include "libmaix_debug.h"
 #include <string.h>
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 typedef struct
 {
     libmaix_nn_decoder_yolo2_config_t* config;
@@ -521,3 +523,6 @@ void libmaix_nn_decoder_yolo2_destroy(libmaix_nn_decoder_t** obj)
     libmaix_nn_decoder_destroy(obj);
 }
 
+#ifdef __cplusplus
+}
+#endif
\ No newline at end of file
